from ingaia.commons.exceptions import GenericException


class IngaiaRLTokenNotDefinedException(GenericException):
    message = 'Define the environment variable "INGAIA_RL_TOKEN" in "app.yaml".'


print(IngaiaRLTokenNotDefinedException())



"""------------------------------
inGaia python utility library
------------------------------
Version: {__version__}
"""

from ingaia import __version__


def main(*args, **kwargs):
    print(__doc__.replace('{__version__}', __version__))


if __name__ == "__main__":
    main()



class RequestLoggerConfig:
    # constants
    DB_STORE = True
    REQUEST_LOGGER_DATA_STORE_URL = 'https://us-central1-joses-request-logger.cloudfunctions.net/request-logger'

    # queue configuration
    REQUEST_LOG_QUEUE_NAME = 'requests-log-queue'
    REQUEST_LOG_QUEUE_URI = '/save-requests-log'

    @classmethod
    def enable_database_store(cls):
        cls.DB_STORE = True

    @classmethod
    def disable_database_store(cls):
        cls.DB_STORE = False


config = RequestLoggerConfig()



from m2r import parse_from_file
from setuptools import setup

# This call to setup() does all the work
setup(
    name="ingaia-libs",
    version="0.0.19",
    description="inGaia Python Utility Library",
    long_description=parse_from_file('Readme.md'),
    long_description_content_type="text/markdown",
    url="http://gitlab.ingaia.com.br/operacoes/libs/ingaia-libs",
    author="inGaia Operations",
    author_email="suporte.operacoes@i-value.com.br",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Operating System :: OS Independent",
    ],
    packages=["ingaia", "ingaia.commons", "ingaia.constants", "ingaia.gcloud", "ingaia.request_logger"],
    include_package_data=False,
    install_requires=["google-cloud-firestore", "google-cloud-datastore", "google-cloud-tasks", "google-cloud-storage",
                      "google-cloud-bigquery", "flask", "google-cloud-scheduler", "werkzeug", "decorator", "requests"],
    entry_points={
        "console_scripts": [
            "ingaia-libs=ingaia.__main__:main",
        ]
    },
)
